DataDetectChapterAndGame class

Constructors

DataDetectChapterAndGame({required String gameType, required int audioFlag, required String programName, required String mobLessonName, required int countOfTries, bool? isArabic})

Properties

audioFlag → int
final
countOfTries ↔ int
getter/setter pair
enumValues ↔ List<String>
getter/setter pair
gameType ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isArabic ↔ bool?
getter/setter pair
mobLessonName ↔ String
getter/setter pair
programName ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited