GameLettersGameFinalModel class

Annotations
  • @JsonSerializable.new(explicitToJson: true, fieldRename: FieldRename.snake)

Constructors

GameLettersGameFinalModel({int? id, String? letter, String? secLetter, String? image, int? number, int? typeOfTool, int? isRun, String? voice, int? hideRings, int? mainQuestion, int? gameId, bool? hide = false, int? warmupId, int? unitId, String? createdAt, String? updatedAt, int? stars})
const
GameLettersGameFinalModel.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt → String?
final
gameId → int?
final
hashCode → int
The hash code for this object.
no setterinherited
hide → bool?
final
hideRings → int?
final
id → int?
final
image → String?
final
isRun → int?
final
letter → String?
final
mainQuestion → int?
final
number → int?
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secLetter → String?
final
stars → int?
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
typeOfTool → int?
final
unitId → int?
final
updatedAt → String?
final
voice → String?
final
warmupId → int?
final

Methods

copyWith({String? subLetter, String? letter}) → GameLettersGameFinalModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited