SnakeGameModel class

Constructors

SnakeGameModel({int? number, SnakeType? stateOfItem, int? id, int? mainNumber, bool isCorrect = false, bool isZero = false, bool isSelected = false, int? numberWillShowStick})

Properties

hashCode → int
The hash code for this object.
no setteroverride
id ↔ int?
getter/setter pair
isCorrect ↔ bool
getter/setter pair
isSelected ↔ bool
getter/setter pair
isZero ↔ bool
getter/setter pair
mainNumber ↔ int?
getter/setter pair
number ↔ int?
getter/setter pair
numberWillShowStick ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateOfItem ↔ SnakeType?
getter/setter pair

Methods

copy() → SnakeGameModel
copyWith({int? id, bool? isCorrect, bool? isSelected, bool? isZero, int? number, int? mainNumber}) → SnakeGameModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override