UserCourseGameFinalModel class

Annotations
  • @JsonSerializable.new(explicitToJson: true, fieldRename: FieldRename.snake)

Constructors

UserCourseGameFinalModel({int? id, int? userId, int? programId, String? createdAt, String? name, String? updatedAt, ProgramGameFinalModel? program})
const
UserCourseGameFinalModel.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → int?
final
name → String?
final
program → ProgramGameFinalModel?
final
programId → int?
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
updatedAt → String?
final
userId → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited